@@ -9,6 +9,9 @@ pub mod week_of {
     pub const MIN_UNIT_DAYS: u16 = 14;
 
     /// Information about how a given calendar assigns weeks to a year or month.
+    #[derive(Clone, Copy, Debug)]
+    #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
+    #[allow(clippy::exhaustive_structs)] // this type is stable
     pub struct CalendarInfo {
         /// The first day of a week.
         pub first_weekday: IsoWeekday,
@@ -23,6 +26,15 @@ pub mod week_of {
         }
     }
 
+    impl Default for CalendarInfo {
+        fn default() -> Self {
+            Self {
+                first_weekday: IsoWeekday::Monday,
+                min_week_days: 1,
+            }
+        }
+    }
+
     /// Returns the weekday that's `num_days` after `weekday`.
     fn add_to_weekday(weekday: IsoWeekday, num_days: i32) -> IsoWeekday {
         let new_weekday = (7 + (weekday as i32) + (num_days % 7)) % 7;
@@ -108,6 +120,7 @@ pub mod week_of {
 
     /// The year or month that a calendar assigns a week to relative to the year/month that it is in.
     #[derive(Debug, PartialEq)]
+    #[allow(clippy::exhaustive_enums)] // this type is stable
     pub enum RelativeUnit {
         /// A week that is assigned to previous year/month. e.g. 2021-01-01 is week 54 of 2020 per the ISO calendar.
         Previous,
@@ -119,6 +132,7 @@ pub mod week_of {
 
     /// The week number assigned to a given week according to a calendar.
     #[derive(Debug, PartialEq)]
+    #[allow(clippy::exhaustive_structs)] // this type is stable
     pub struct WeekOf {
         /// Week of month/year. 1 based.
         pub week: u16,
@@ -170,6 +184,32 @@ pub mod week_of {
         }
     }
 
+    /// Computes & returns the week of given month or year accoding to a calendar with min_week_days = 1.
+    ///
+    /// # Arguments
+    ///  - first_weekday: The first day of a week.
+    ///  - day: 1-based day of the month or year.
+    ///  - week_day: The weekday of `day`.
+    pub fn simple_week_of(first_weekday: IsoWeekday, day: u16, week_day: IsoWeekday) -> u16 {
+        let calendar = CalendarInfo {
+            first_weekday,
+            min_week_days: 1,
+        };
+
+        #[allow(clippy::expect_used)] // TODO(#1668) Clippy exceptions need docs or fixing.
+        week_of(
+            &calendar,
+            // The duration of the current and previous unit does not influence the result if min_week_days = 1
+            // so we only need to use a valid value.
+            MIN_UNIT_DAYS,
+            MIN_UNIT_DAYS,
+            day,
+            week_day,
+        )
+        .expect("week_of should can't fail with MIN_UNIT_DAYS")
+        .week
+    }
+
     #[cfg(test)]
     mod tests {
         use super::{week_of, CalendarInfo, RelativeUnit, RelativeWeek, UnitInfo, WeekOf};
@@ -411,4 +451,29 @@ pub mod week_of {
             Ok(())
         }
     }
+
+    #[test]
+    fn test_simple_week_of() {
+        // The 1st is a Monday and the week starts on Mondays.
+        assert_eq!(
+            simple_week_of(IsoWeekday::Monday, 2, IsoWeekday::Tuesday),
+            1
+        );
+        assert_eq!(simple_week_of(IsoWeekday::Monday, 7, IsoWeekday::Sunday), 1);
+        assert_eq!(simple_week_of(IsoWeekday::Monday, 8, IsoWeekday::Monday), 2);
+
+        // The 1st is a Wednesday and the week starts on Tuesdays.
+        assert_eq!(
+            simple_week_of(IsoWeekday::Tuesday, 1, IsoWeekday::Wednesday),
+            1
+        );
+        assert_eq!(
+            simple_week_of(IsoWeekday::Tuesday, 6, IsoWeekday::Monday),
+            1
+        );
+        assert_eq!(
+            simple_week_of(IsoWeekday::Tuesday, 7, IsoWeekday::Tuesday),
+            2
+        );
+    }
 }
