@@ -2,16 +2,41 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-//! This module contains types and implementations for the ISO calendar
+//! This module contains types and implementations for the ISO calendar.
+//!
+//! ```rust
+//! use icu::calendar::{Date, DateTime,
+//!                     types::IsoHour, types::IsoMinute, types::IsoSecond};
+//!
+//! // `Date` type
+//! let date_iso = Date::new_iso_date_from_integers(1970, 1, 2).unwrap();
+//!
+//! // `DateTime` type
+//! let datetime_iso = DateTime::new_iso_datetime_from_integers(1970, 1, 2, 13, 1, 0).unwrap();
+//!
+//! // `Date` checks
+//! assert_eq!(date_iso.year().number, 1970);
+//! assert_eq!(date_iso.month().number, 1);
+//! assert_eq!(date_iso.day_of_month().0, 2);
+//!
+//! // `DateTime` type
+//! assert_eq!(datetime_iso.date.year().number, 1970);
+//! assert_eq!(datetime_iso.date.month().number, 1);
+//! assert_eq!(datetime_iso.date.day_of_month().0, 2);
+//! assert_eq!(datetime_iso.time.hour, IsoHour::new_unchecked(13));
+//! assert_eq!(datetime_iso.time.minute, IsoMinute::new_unchecked(1));
+//! assert_eq!(datetime_iso.time.second, IsoSecond::new_unchecked(0));
+//! ```
 
 use crate::{types, Calendar, Date, DateDuration, DateDurationUnit, DateTime, DateTimeError};
 use core::convert::{TryFrom, TryInto};
-use tinystr::{tinystr16, tinystr8};
+use tinystr::tinystr;
 
 // The georgian epoch is equivalent to first day in fixed day measurement
 const EPOCH: i32 = 1;
 
 #[derive(Copy, Clone, Debug, Default)]
+#[allow(clippy::exhaustive_structs)] // this type is stable
 /// The ISO Calendar
 pub struct Iso;
 
@@ -22,6 +47,7 @@ pub struct IsoDay(u8);
 #[derive(Copy, Clone, Debug, Hash, Eq, PartialEq, Ord, PartialOrd)]
 pub struct IsoMonth(u8);
 #[derive(Copy, Clone, Debug, Hash, Eq, PartialEq, Ord, PartialOrd)]
+#[allow(clippy::exhaustive_structs)] // newtype
 /// An ISO year. Year 0 == 1 BCE
 pub struct IsoYear(pub i32);
 
@@ -72,7 +98,7 @@ impl From<IsoYear> for i32 {
 impl From<IsoYear> for types::Year {
     fn from(year: IsoYear) -> types::Year {
         types::Year {
-            era: types::Era(tinystr16!("default")),
+            era: types::Era(tinystr!(16, "default")),
             number: year.0,
             related_iso: year.0,
         }
@@ -84,7 +110,7 @@ impl From<IsoMonth> for types::Month {
         types::Month {
             number: month.0 as u32,
             // TODO(#486): Implement month codes
-            code: types::MonthCode(tinystr8!("TODO")),
+            code: types::MonthCode(tinystr!(8, "TODO")),
         }
     }
 }
@@ -252,6 +278,7 @@ impl Calendar for Iso {
         &self,
         date1: &Self::DateInner,
         date2: &Self::DateInner,
+        _calendar2: &Self,
         _largest_unit: DateDurationUnit,
         _smallest_unit: DateDurationUnit,
     ) -> DateDuration<Self> {
@@ -293,13 +320,32 @@ impl Calendar for Iso {
         }
     }
 
-    fn debug_name() -> &'static str {
+    fn debug_name(&self) -> &'static str {
         "ISO"
     }
 }
 
 impl Date<Iso> {
-    /// Construct a new ISO Date
+    /// Construct a new ISO Date.
+    ///
+    /// ```rust
+    /// use icu::calendar::{Date,
+    ///                     iso::IsoYear,
+    ///                     iso::IsoMonth,
+    ///                     iso::IsoDay};
+    /// use std::convert::TryFrom;
+    ///
+    /// let iso_year = IsoYear(1996);
+    /// let iso_month = IsoMonth::try_from(2).unwrap();
+    /// let iso_day = IsoDay::try_from(3).unwrap();
+    ///
+    /// // Creation of ISO date
+    /// let date_iso = Date::new_iso_date(iso_year, iso_month, iso_day).unwrap();
+    ///
+    /// assert_eq!(date_iso.year().number, 1996);
+    /// assert_eq!(date_iso.month().number, 2);
+    /// assert_eq!(date_iso.day_of_month().0, 3);
+    /// ```
     pub fn new_iso_date(
         year: IsoYear,
         month: IsoMonth,
@@ -315,7 +361,17 @@ impl Date<Iso> {
         Ok(Date::from_raw(IsoDateInner { day, month, year }, Iso))
     }
 
-    /// Construct a new ISO date from integers
+    /// Construct a new ISO date from integers.
+    ///
+    /// ```rust
+    /// use icu::calendar::Date;
+    ///
+    /// let date_iso = Date::new_iso_date_from_integers(1970, 1, 2).unwrap();
+    ///
+    /// assert_eq!(date_iso.year().number, 1970);
+    /// assert_eq!(date_iso.month().number, 1);
+    /// assert_eq!(date_iso.day_of_month().0, 2);
+    /// ```
     pub fn new_iso_date_from_integers(
         year: i32,
         month: u8,
@@ -326,7 +382,23 @@ impl Date<Iso> {
 }
 
 impl DateTime<Iso> {
-    /// Construct a new ISO date from integers
+    /// Construct a new ISO date from integers.
+    ///
+    /// ```rust
+    /// use icu::calendar::{DateTime,
+    ///                     types::IsoHour,
+    ///                     types::IsoMinute,
+    ///                     types::IsoSecond};
+    ///
+    /// let datetime_iso = DateTime::new_iso_datetime_from_integers(1970, 1, 2, 13, 1, 0).unwrap();
+    ///
+    /// assert_eq!(datetime_iso.date.year().number, 1970);
+    /// assert_eq!(datetime_iso.date.month().number, 1);
+    /// assert_eq!(datetime_iso.date.day_of_month().0, 2);
+    /// assert_eq!(datetime_iso.time.hour, IsoHour::new_unchecked(13));
+    /// assert_eq!(datetime_iso.time.minute, IsoMinute::new_unchecked(1));
+    /// assert_eq!(datetime_iso.time.second, IsoSecond::new_unchecked(0));
+    /// ```
     pub fn new_iso_datetime_from_integers(
         year: i32,
         month: u8,
@@ -337,7 +409,7 @@ impl DateTime<Iso> {
     ) -> Result<DateTime<Iso>, DateTimeError> {
         Ok(DateTime {
             date: Date::new_iso_date_from_integers(year, month, day)?,
-            time: types::Time::try_new(hour, minute, second)?,
+            time: types::Time::try_new(hour, minute, second, 0)?,
         })
     }
 }
@@ -395,6 +467,7 @@ impl Iso {
     }
 
     fn fixed_from_iso_integers(year: i32, month: i32, day: i32) -> i32 {
+        #[allow(clippy::unwrap_used)] // TODO(#1668) Clippy exceptions need docs or fixing.
         Self::fixed_from_iso(
             *Date::new_iso_date_from_integers(year, month as u8, day as u8)
                 .unwrap()
@@ -444,13 +517,32 @@ impl Iso {
         };
         let month = (12 * (prior_days + correction) + 373) / 367;
         let day = date - Self::fixed_from_iso_integers(year, month, 1) + 1;
+        #[allow(clippy::unwrap_used)] // TODO(#1668) Clippy exceptions need docs or fixing.
         Date::new_iso_date_from_integers(year, month as u8, day as u8).unwrap()
     }
 
+    pub(crate) fn iso_from_year_day(year: i32, year_day: u32) -> Date<Iso> {
+        let mut month = 1;
+        let mut day = year_day as i32;
+        while month <= 12 {
+            let month_days = Self::days_in_month(IsoYear(year), IsoMonth(month)) as i32;
+            if day <= month_days {
+                break;
+            } else {
+                day -= month_days;
+                month += 1;
+            }
+        }
+
+        #[allow(clippy::unwrap_used)] // TODO(#1668) Clippy exceptions need docs or fixing.
+        Date::new_iso_date_from_integers(year, month, day.try_into().unwrap()).unwrap()
+    }
+
     pub(crate) fn day_of_year(date: IsoDateInner) -> u32 {
         // Cumulatively how much are dates in each month
         // offset from "30 days in each month" (in non leap years)
         let month_offset = [0, 1, -1, 0, 0, 1, 1, 2, 3, 3, 4, 4];
+        #[allow(clippy::indexing_slicing)] // TODO(#1668) Clippy exceptions need docs or fixing.
         let mut offset = month_offset[date.month.0 as usize - 1];
         if Self::is_leap_year(date.year) && date.month.0 > 2 {
             // Months after February in a leap year are offset by one less
